==> haskell-non-negative-0.1.2-246-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-non-negative.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 non-negative
version:              0.1.2
visibility:           public
id:                   non-negative-0.1.2-JuDWFceoop8D5VckG749wO
key:                  non-negative-0.1.2-JuDWFceoop8D5VckG749wO
license:              LicenseRef-GPL
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:               Henning Thielemann <haskell@henning-thielemann.de>
homepage:             http://code.haskell.org/~thielema/non-negative/
synopsis:             Non-negative numbers
description:
    Provides a class for non-negative numbers,
    a wrapper which can turn any ordered numeric type into a member of that class,
    and a lazy number type for non-negative numbers
    (a generalization of Peano numbers).
    This library is used by the @event-list@ package.

category:             Math
abi:                  3573f0a8eefbc56ffa0067d8e096d6a8
exposed:              True
exposed-modules:
    Numeric.NonNegative.Chunky Numeric.NonNegative.Class
    Numeric.NonNegative.Wrapper

hidden-modules:       Numeric.NonNegative.ChunkyPrivate
import-dirs:          /usr/lib/ghc-9.2.8/site-local/non-negative-0.1.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/non-negative-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-non-negative
hs-libraries:         HSnon-negative-0.1.2-JuDWFceoop8D5VckG749wO
depends:
    QuickCheck-2.14.3-AB831W8sF74KL3cz7DxP1X base-4.16.4.0
    utility-ht-0.0.17.2-7hfxNAxwKoFLnCNbU4FWYa

haddock-interfaces:
    /usr/share/doc/haskell-non-negative/html/non-negative.haddock

haddock-html:         /usr/share/doc/haskell-non-negative/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-non-negative-0.1.2-274.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-non-negative.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 non-negative
version:              0.1.2
visibility:           public
id:                   non-negative-0.1.2-JmHfzux9f3dAWKN3VEiozJ
key:                  non-negative-0.1.2-JmHfzux9f3dAWKN3VEiozJ
license:              LicenseRef-GPL
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:               Henning Thielemann <haskell@henning-thielemann.de>
homepage:             http://code.haskell.org/~thielema/non-negative/
synopsis:             Non-negative numbers
description:
    Provides a class for non-negative numbers,
    a wrapper which can turn any ordered numeric type into a member of that class,
    and a lazy number type for non-negative numbers
    (a generalization of Peano numbers).
    This library is used by the @event-list@ package.

category:             Math
abi:                  5ea8155b02c8ab39015cf334f84bb2a2
exposed:              True
exposed-modules:
    Numeric.NonNegative.Chunky Numeric.NonNegative.Class
    Numeric.NonNegative.Wrapper

hidden-modules:       Numeric.NonNegative.ChunkyPrivate
import-dirs:          /usr/lib/ghc-9.4.8/site-local/non-negative-0.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/non-negative-0.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/non-negative-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-non-negative
hs-libraries:         HSnon-negative-0.1.2-JmHfzux9f3dAWKN3VEiozJ
depends:
    QuickCheck-2.14.3-Gpw9UoHUxB71c0Trj8n39O base-4.17.2.1
    utility-ht-0.0.17.2-CDH9qhWDx4z3BQ085GTPlX

haddock-interfaces:
    /usr/share/doc/haskell-non-negative/html/non-negative.haddock

haddock-html:         /usr/share/doc/haskell-non-negative/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
